# eric7.Plugins.UiExtensionPlugins.Translator.TranslatorEngines.PromtEngine

Module implementing the Promt translation engine.

### Global Attributes

None

### Classes

PromtEngine | Class implementing the translation engine for the Promt translation service.

### Functions

None

## PromtEngine

Class implementing the translation engine for the Promt translation service.

### Derived from

TranslationEngine

### Class Attributes

TranslatorUrl

### Class Methods

None

### Methods

PromtEngine | Constructor
engineName | Public method to return the name of the engine.
getTranslation | Public method to translate the given text.
supportedLanguages | Public method to get the supported languages.

### Static Methods

None

#### PromtEngine (Constructor)

PromtEngine(plugin, parent=None)

Constructor

plugin
  reference to the plugin object (TranslatorPlugin)
parent
  reference to the parent object (QObject)

#### PromtEngine.engineName

engineName()

Public method to return the name of the engine.

Return:
  engine name (string)

#### PromtEngine.getTranslation

getTranslation(requestObject, text, originalLanguage, translationLanguage)

Public method to translate the given text.

requestObject
  reference to the request object (TranslatorRequest)
text
  text to be translated (string)
originalLanguage
  language code of the original (string)
translationLanguage
  language code of the translation (string)

Return:
  tuple of translated text (string) and flag indicating success (boolean)

#### PromtEngine.supportedLanguages

supportedLanguages()

Public method to get the supported languages.

Return:
  list of supported language codes (list of string)

Up